<?php
/**
 * This class handles communication with ORS and should not be tempered wiht! 
 * 
 * Any changes that you made to this class could result in fault behaviour and ORS is not held responsible for!
 * 
 * @author Gregor Flajs , gregor.flajs@ors.si
 *
 */

ini_set("default_socket_timeout", 120); // Change default socket timeout parameter otherwise a connections are droping!


class orsibe{
	
	private $orsSoapClient;
	private $soapUserInfo;
	
	private $headInfo;
	private $sessionId;
	
	function orsibe($data){
		$this->setSoapClient($data);
	}
	
	
	// ================================= GETTERS ============================== //
	// ================================= GETTERS ============================== //
	// ================================= GETTERS ============================== //
	
	function getORSSC(){
		return $this->orsSoapClient;
	}
	
	
	function getIBETitle(){
		return $this->headInfo['title'];
	}	
	
	function getORSBodyScripts(){
		return $this->headInfo['body_scripts'];
	}
	
	function getORSScripts(){
		return $this->headInfo['scripts'];
	}	
	
	function getORSStyles(){
		return $this->headInfo['styles'];
	}
	
	function getHeaderInfo(){
		$this->headInfo = $this->orsSoapClient->getHeaderInfo($this->soapUserInfo, $_GET);
		return $this->headInfo;
	}

	function fb($getData){
		return $this->orsSoapClient->fb($this->soapUserInfo, $getData);
	}
	
	function getAjaxReq($getData, $scriptFile = ''){
		$info = $this->orsSoapClient->getAjaxReq($this->soapUserInfo, $getData, $scriptFile);
		return $info;
	}
	
	function getIBEContent(){
		return $this->headInfo['ibe_content'];
	}
	
	// ================================= SETTERS ============================== //
	// ================================= SETTERS ============================== //
	// ================================= SETTERS ============================== //
	
	/**
	 * Cookie is used for storing session ID. A cookie timeout can be set in config file.
	 */
	function setCookie(){
		if (isset($_COOKIE[ORSIBE_COOKIE])) { // if cookie exist then read session id			
			$cookie_data = unserialize($_COOKIE[ORSIBE_COOKIE]);
			
			if (empty($cookie_data['orsibe_sessionid'])){
				session_start();
				$this->sessionId = session_id();
			}else
				$this->sessionId = $cookie_data['orsibe_sessionid']; 
			
			$this->updateCookie();
		}else{
			session_start();
			$this->sessionId = session_id();
			
			$cookie_data = array(
				'orsibe_sessionid' => $this->sessionId,
				'orsibe_id' => ORSIBE_ID,
				'orsibe_user' => ORSIBE_USER,
				'orsibe_theme' => ORSIBE_THEME,
				'orsibe_default_typ' => ORSIBE_DEFAULT_TYP,
				'orsibe_default_toc' => ORSIBE_DEFAULT_TOC,
				'orsibe_lang' => ORSIBE_LANG,
			
				'orsibe_bookingmail' => ORSIBE_BOOKING_MAIL,
				'orsibe_bookingmail_replyto' => ORSIBE_BOOKING_REPLY_MAIL,
				'orsibe_bookingmail_fromname' => ORSIBE_BOOKING_FROM_NAME,
				'orsibe_bookingmail_subject' => ORSIBE_BOOKING_SUBJECT,			
			);
			
			setcookie(ORSIBE_COOKIE,serialize($cookie_data),time()-(60*60*24*ORSIBE_COOKIE_TIMEOUT),"/",ORSIBE_COOKIE_DOMAIN);
			setcookie(ORSIBE_COOKIE,serialize($cookie_data),time()+(60*60*24*ORSIBE_COOKIE_TIMEOUT),"/",ORSIBE_COOKIE_DOMAIN);
		}
	}
	
	/**
	 * Cookies must be updated if agency changes it's data.
	 */
	function updateCookie(){
		$cookie_data = array(
			'orsibe_sessionid' => $this->sessionId,
			'orsibe_id' => ORSIBE_ID,
			'orsibe_user' => ORSIBE_USER,
			'orsibe_theme' => ORSIBE_THEME,
			'orsibe_default_typ' => ORSIBE_DEFAULT_TYP,
			'orsibe_default_toc' => ORSIBE_DEFAULT_TOC,
			'orsibe_lang' => ORSIBE_LANG,
		
			'orsibe_bookingmail' => ORSIBE_BOOKING_MAIL,
			'orsibe_bookingmail_replyto' => ORSIBE_BOOKING_REPLY_MAIL,
			'orsibe_bookingmail_fromname' => ORSIBE_BOOKING_FROM_NAME,
			'orsibe_bookingmail_subject' => ORSIBE_BOOKING_SUBJECT,			
		);

		setcookie(ORSIBE_COOKIE,serialize($cookie_data),time()-(60*60*24*ORSIBE_COOKIE_TIMEOUT),"/",ORSIBE_COOKIE_DOMAIN);
		setcookie(ORSIBE_COOKIE,serialize($cookie_data),time()+(60*60*24*ORSIBE_COOKIE_TIMEOUT),"/",ORSIBE_COOKIE_DOMAIN);
	}
	
	/**
	 * Init Soap.
	 * 
	 * @param $data
	 */
	function setSoapClient($data){
		$this->setCookie();
		
		$this->orsSoapClient = new SoapClient(null, array(
			'location' => ORS_SOAP_LOCATION,
			'uri'      => ORS_SOAP_URI,
			'trace'    => 1)
		);
		
		
		$this->soapUserInfo = array(
			'orsibe_id' => ORSIBE_ID,
			'orsibe_user' => ORSIBE_USER,
			'orsibe_pass' => ORSIBE_PASS,
			'orsibe_lang' => ORSIBE_LANG,
			'orsibe_sessionid' => $this->sessionId,
			'orsibe_path' => ORSIBE_PATH,
			'orsibe_host' => ORSIBE_HOST,
			'orsibe_domain' => ORSIBE_DOMAIN,
			'orsibe_theme' => ORSIBE_THEME,			
			'orsibe_default_typ' => ORSIBE_DEFAULT_TYP,
			'orsibe_default_toc' => ORSIBE_DEFAULT_TOC,
			'orsibe_cookie' => ORSIBE_COOKIE,			

			'orsibe_bookingmail' => ORSIBE_BOOKING_MAIL,
			'orsibe_bookingmail_replyto' => ORSIBE_BOOKING_REPLY_MAIL,
			'orsibe_bookingmail_fromname' => ORSIBE_BOOKING_FROM_NAME,
			'orsibe_bookingmail_subject' => ORSIBE_BOOKING_SUBJECT,
		
			'orsibe_max_ka' => ORSIBE_MAX_CHILD_AGE,
		);
		
		$logged = $this->orsSoapClient->login($this->soapUserInfo);
		 
		 
		if (!$logged) die('Invalid username or password. Please contact ORS!');
	}
	
	
}

?>